Err<T, E> class

A type that represents the failure Result of something.

Pattern matching is recommended for interacting with Result types.

Result<int, String> foo = Err('panic!');

if (foo case Err(value: var err)) {
  print('Error value: $err');
}
Inheritance
Available extensions

Constructors

Err(E value)
const

Properties

e → E
no setter
error → E
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
v → E
no setter
val → E
no setter
value → E
final

Methods

and<U>(Result<U, E> other) → Result<U, E>
Returns a Result value as Err<U, E> if this Result is Err<T, E>, otherwise returns other.
inherited
andThen<U>(Result<U, E> fn(T)) → Result<U, E>
Returns a Result value as Err<U, E> if this Result is Err<T, E>, otherwise calls fn with the held Ok value and returns the returned Result.
inherited
call() → T
Shortcut to call Result.unwrap().
inherited
err() → Option<E>
Converts this Result<T, E> into an Option<E>, discarding the held value if this is Ok.
inherited
expect(String message) → T
Returns the held value of this Result if it is Ok. Throws a ResultError with the given message and held Err value if this Result is Err.
inherited
expectErr(String message) → E
Returns the held value of this Result if it is Err. Throws a ResultError with the given message and held Ok value if this Result is Ok.
inherited
flatten() → Result<T, E>

Available on Result<Result<T, E>, E>, provided by the ResultFlatten extension

Flattens a nested Result type value one level.
inspect(void fn(T)) → Result<T, E>
Calls the provided function with the contained value if this Result is Ok.
inherited
inspectErr(void fn(E)) → Result<T, E>
Calls the provided function with the contained error value if this Result is Err.
inherited
isErr() → bool
Returns whether or not this Result is Err.
inherited
isErrAnd(bool predicate(E)) → bool
Returns whether or not this Result is Err and that the held error value matches the given predicate.
inherited
isOk() → bool
Returns whether or not this Result is Ok.
inherited
isOkAnd(bool predicate(T)) → bool
Returns whether or not this Result is Ok and that the held value matches the given predicate.
inherited
iter() → Iterable<T>
Returns an Iterable of the held value.
inherited
map<U>(U mapFn(T)) → Result<U, E>
Maps a Result<T, E> to a Result<U, E> using the given function with the held value.
inherited
mapErr<F>(F mapFn(E)) → Result<T, F>
Maps a Result<T, E> to a Result<T, F> using the given function with the held value.
inherited
mapOr<U>(U orValue, U mapFn(T)) → Result<U, E>
Maps a Result<T, E> to a Result<U, E> using the given function with the held value if the Result<T, E> is Ok. Otherwise returns the provided orValue as Ok(orValue).
inherited
mapOrElse<U>(U orFn(), U mapFn(T)) → Result<U, E>
Maps a Result<T, E> to a Result<U, E> using the given mapFn function with the held value if the Result is Ok. Otherwise returns the result of orFn as Ok(orFn()).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ok() → Option<T>
Converts this Result<T, E> into an Option<T>, discarding the held error value if this is Err.
inherited
or<F>(Result<T, F> other) → Result<T, F>
Returns a Result value as Ok<T, F> if this Result is Ok<T, E>, otherwise returns other.
inherited
orElse<F>(Result<T, F> fn(E)) → Result<T, F>
Returns a Result value as Ok<T, F> if this Result is Ok<T, E>, otherwise calls fn with the held Err value and returns the returned Result.
inherited
toString() → String
A string representation of this object.
inherited
transpose() → Option<Result<T, E>>

Available on Result<Option<T>, E>, provided by the ResultTranspose extension

Transposes this Result<Option<T>, E> into an Option<Result<T, E>>.
unwrap() → T
Returns the held value of this Result if it is Ok.
inherited
unwrapErr() → E
Returns the held value of this Result if it is Err.
inherited
unwrapOr(T orValue) → T
Returns the held value of this Result if it is Ok, or the given value if this Result is Err.
inherited
unwrapOrElse(T elseFn()) → T
Returns the held value of this Result if it is Ok, or returns the returned value from elseFn if this Result is Err.
inherited

Operators

operator ==(Object other) → bool
Compare equality between two Result values.
inherited